@@ -42,7 +42,7 @@ class EndpointData():
 			"ap-northeast-1": "mongodb.ap-northeast-1.aliyuncs.com",
 			"cn-huhehaote-nebula-1": "mongodb.aliyuncs.com",
 			"cn-shanghai-et2-b01": "mongodb.aliyuncs.com",
-			"ap-southeast-1": "mongodb.aliyuncs.com",
+			"ap-southeast-1": "mongodb.ap-southeast-1.aliyuncs.com",
 			"ap-southeast-2": "mongodb.ap-southeast-2.aliyuncs.com",
 			"ap-southeast-3": "mongodb.ap-southeast-3.aliyuncs.com",
 			"ap-southeast-5": "mongodb.ap-southeast-5.aliyuncs.com",
@@ -58,7 +58,7 @@ class EndpointData():
 			"cn-hongkong-finance-pop": "mongodb.aliyuncs.com",
 			"cn-shanghai": "mongodb.aliyuncs.com",
 			"cn-shanghai-finance-1": "mongodb.aliyuncs.com",
-			"cn-hongkong": "mongodb.aliyuncs.com",
+			"cn-hongkong": "mongodb.cn-hongkong.aliyuncs.com",
 			"eu-central-1": "mongodb.eu-central-1.aliyuncs.com",
 			"cn-shenzhen": "mongodb.aliyuncs.com",
 			"cn-zhengzhou-nebula-1": "mongodb.aliyuncs.com",
