@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkdds.endpoint import endpoint_data
 
 class EvaluateResourceRequest(RpcRequest):
 
@@ -25,6 +26,11 @@ class EvaluateResourceRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'EvaluateResource','dds')
 		self.set_method('POST')
 
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
@@ -55,11 +61,6 @@ class EvaluateResourceRequest(RpcRequest):
 
 	def set_ReplicationFactor(self, ReplicationFactor):  # String
 		self.add_query_param('ReplicationFactor', ReplicationFactor)
-	def get_SecurityToken(self): # String
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self, SecurityToken):  # String
-		self.add_query_param('SecurityToken', SecurityToken)
 	def get_Engine(self): # String
 		return self.get_query_params().get('Engine')
 
